@@ -1,7 +1,9 @@
 package arcos;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: arcos.pm.in 3959 2019-01-23 03:36:20Z heas $
+##
+## rancid 3.9
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -55,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.9;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -134,12 +136,6 @@ sub ShowVersion {
 	return(1) if (/Line has invalid autocommand /);
 	return(1) if (/(invalid (input|command) detected|type help or )/i);
 	return(-1) if (/command authorization failed/i);
-	return(-1) if (/error: application communication failure/i);
-
-	# drop trailing spaces
-	s/  *$//;
-
-	/uptime:/i && next;
 
 	/version product-name "([^\"]*)"/ &&
 	    ProcessHistory("COMMENTS","keysort","A1",
@@ -155,6 +151,25 @@ sub ShowVersion {
     ProcessHistory("COMMENTS","keysort","VERSION","!\n");
     return(0);
 }
+# This routine parses "show features"
+sub ShowFeatures {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In ShowVersion: $_" if ($debug);
+
+    while (<$INPUT>) {
+	tr/\015//d;
+	next if (/^(\s*|\s*$cmd\s*)$/);
+	last if (/^$prompt/);
+	next if (/^\s+\^$/);
+	return(1) if (/Line has invalid autocommand /);
+	return(1) if (/(invalid (input|command) detected|type help or )/i);
+	return(-1) if (/command authorization failed/i);
+
+	ProcessHistory("","","","! $_");
+    }
+    ProcessHistory("","","","!\n");
+    return(0);
+}
 
 # This routine parses "show hardware"
 sub ShowHardware {
@@ -169,23 +184,6 @@ sub ShowHardware {
 	return(1) if (/Line has invalid autocommand /);
 	return(1) if (/(invalid (input|command) detected|type help or )/i);
 	return(-1) if (/command authorization failed/i);
-	return(-1) if (/error: application communication failure/i);
-
-	# skip allocated, free, watermarks & their timestamps
-	next if (/(estimated-free|objects-allocated|high-watermark|raw-(free|used))/);
-	# skip feature tables
-	if (/\s*feature$/) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		next if (/^(\s*|\s*$cmd\s*)$/);
-		last if (/^$prompt/);
-		last if (/^\s*$/);
-	    }
-	}
-
-	# drop indexer counts
-	next if (/^\s+used\s+\d+/);
-	next if (/^\s+hold-count\s+\d+/);
 
 	# XXX for now, drop the per-unit information.  Appears to be mostly
 	# useless.
@@ -216,7 +214,6 @@ TOP:
 	return(1) if (/(Open device \S+ failed|Error opening \S+:)/);
 	return(0) if ($found_end);		# Only do this routine once
 	return(-1) if (/command authorization failed/i);
-	return(-1) if (/error: application communication failure/i);
 	return(-1) if (/% ?configuration buffer full/i);
 
 	/^! no configuration change since last restart/i && next;
