@@ -1,12 +1,12 @@
 package dell;
 ##
-## $Id: dell.pm.in 3699 2017-07-18 13:40:55Z heas $
+## $Id: dell.pm.in 3936 2018-12-17 21:32:17Z heas $
 ##
 ## fnrancid patched to dlrancid to accomplish D-Link support
 ## adapted by: Gavin McCullagh <gmccullagh at gmail.com>
 ##             Griffith College Dublin
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -71,7 +71,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.8;
+use rancid 3.9;
 
 our $proc;
 our $found_version;
@@ -103,7 +103,7 @@ sub inloop {
 TOP: while(<$INPUT>) {
 	tr/\015//d;
 	# XXX this match is not correct for DELL
-	if (/[>#]\s?exit$/) {
+	if (/[>#]\s?exit(?:$|Connection)/) {
 	    $clean_run = 1;
 	    last;
 	}
