@@ -1,7 +1,9 @@
 package fortigate;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: fortigate.pm.in 3869 2018-08-19 11:28:06Z heas $
+##
+## rancid 3.9
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -58,7 +60,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.9;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -139,15 +141,12 @@ sub GetSystem {
 
 	if ($filter_osc >= 2) {
 	    next if (/^\s*APP-DB: .*/);
-	    next if (/^\s*AV AI\/ML Model:: .*/);
 	    next if (/^\s*Botnet DB: .*/);
 	    next if (/^\s*Extended DB: .*/);
 	    next if (/^\s*industrial-db: .*/i);
 	    next if (/^\s*IPS-DB: .*/);
 	    next if (/^\s*IPS-ETDB: .*/);
 	    next if (/^\s*IPS Malicious URL Database: .*/);
-	    next if (/^\s*Proxy-APP-DB: .*/);
-	    next if (/^\s*Proxy-IPS-ETDB: .*/);
 	    next if (/^\s*Virus-DB: .*/);
 	}
 	next if (/^system time:/i);
