@@ -1,8 +1,8 @@
 package iosxr;
 ##
-## $Id: iosxr.pm.in 3841 2018-07-18 16:22:59Z heas $
+## $Id: iosxr.pm.in 3886 2018-09-12 23:48:37Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -57,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.8;
+use rancid 3.9;
 
 our $proc;
 our $found_env;
@@ -597,20 +597,23 @@ sub DirSlotN {
 	# filter frequently changing files from IOX bootflash, hardiska,
 	# and nvram
 	if ($dev =~ /(bootflash|disk0|harddisk|nvram)/) {
-	    if (/\s(\.python-history|aaa|\.bash_history|ce_switch.log)\s*$/ ||
-	        /\s(cisco_support|errmsg_cont|genstr_cont|temp_cont)\s*$/ ||
-	        /\s(temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/) {
+	    if (/\s(\.python-history|aaa|\.bash_history)\s*$/ ||
+	        /\s(ce_switch.log\S*|cisco_support|errmsg_cont)\s*$/ ||
+	        /\s(genstr_cont|temp_cont|temp_cont|temp_static_data)\s*$/ ||
+	        /\s(uptime_cont|volt_cont)\s*$/) {
 		# change
 		# 57          -rw-  23100       <no date>              volt_cont
 		# 614788      drwx  4096        Fri Aug 20 12:06:25 2010  temp_cont
 		# to
 		# 57          -rw-              <no date>              volt_cont
 		# 614788      drwx                                        temp_cont
-		if (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(<no date> )/) {
-		    my($a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
+		if (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(<no date>)(\s+)/) {
+		    my($a, $sz, $c, $dt, $d, $rem) = ($1, $2, $3, $4, $5, $');
 		    my($szl) = length($sz);
-		    my($fmt) = "%s%-". $szl ."s%s%s%s";
-		    $_ = sprintf($fmt, $a, "", $c, $dt, $rem);
+		    my($fmt) = "%s%-". $szl ."s%s%s%s%s";
+		    $_ = sprintf($fmt, $a, "", $c, $dt, $d, $rem);
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
 		} elsif (/(\s*\d+)(\s+\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d+:\d+)/) {
 		    # XR >= 6.3; dir disk0:, but harddisk: is diff format.  wtf
 		    # drop fileno size, & date.
@@ -619,11 +622,34 @@ sub DirSlotN {
 		    my($fnl, $dtl) = (length($fn), length($dt));
 		    my($fmt) = "%-". $fnl ."s%s%-". $dtl ."s%s";
 		    $_ = sprintf($fmt, "", $perm, "", $rem);
-		} elsif (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
-		    my($a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
-		    my($szl, $dtl) = (length($sz), length($dt));
-		    my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
-		    $_ = sprintf($fmt, $a, "", $c, "", $rem);
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
+		} elsif (/(\s*)(\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
+		    my($a, $fn, $b, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5,
+							   $6, $');
+		    my($fnl, $szl, $dtl) = (length($fn), length($sz),
+					    length($dt));
+		    my($fmt) = "%s%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s";
+		    $_ = sprintf($fmt, $a, "", $b, "", $c, "", $rem);
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
+		}
+	    } else {
+		if (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(<no date>)(\s+)/) {
+		    my($a, $sz, $c, $dt, $d, $rem) = ($1, $2, $3, $4, $5, $');
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
+		} elsif (/(\s*\d+)(\s+\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d+:\d+)/) {
+		    # XR >= 6.3; dir disk0:, but harddisk: is diff format.  wtf
+		    my($fn, $perm, $dt, $rem) = ($1, $2, $3, $');
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
+		} elsif (/(\s*)(\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
+		    # XR < 6.3 & etc.
+		    my($a, $fn, $b, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5,
+							   $6, $');
+		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
+		    next;
 		}
 	    }
 	}
