@@ -1,8 +1,8 @@
 package junos;
 ##
-## $Id: junos.pm.in 3788 2018-04-06 23:42:45Z heas $
+## $Id: junos.pm.in 3961 2019-01-24 18:42:17Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -58,9 +58,11 @@ require(Exporter);
 our @ISA = qw(Exporter);
 $Exporter::Verbose=1;
 
-use rancid 3.8;
+use rancid 3.9;
 
 our $ShowChassisSCB;			# Only run ShowChassisSCB() once
+our $ShowChassisFirmware;		# Only run ShowChassisFirmware() once
+
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -75,6 +77,7 @@ sub init {
     # add content lines and separators
     ProcessHistory("","","","#RANCID-CONTENT-TYPE: $devtype\n#\n");
 
+    $junos::ShowChassisFirmware = 0;
     0;
 }
 
@@ -88,7 +91,7 @@ TOP: while (<$INPUT>) {
 	if (/^Error:/) {
 	    print STDOUT ("$host jlogin error: $_");
 	    print STDERR ("$host jlogin error: $_") if ($debug);
-	    $clean_run=0;
+	    $clean_run = 0;
 	    last;
 	}
 	if (/System shutdown message/) {
@@ -130,7 +133,7 @@ TOP: while (<$INPUT>) {
 	    }
 	}
 	if (/>\s*quit/) {
-	    $clean_run=1;
+	    $clean_run = 1;
 	    last;
 	}
     }
@@ -226,10 +229,11 @@ sub ShowChassisFirmware {
     while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
-	return 1 if (/^aborted!/i);
+	return(1) if (/^aborted!/i);
 	next if (/^system (shutdown message from|going down )/i);
 	next if (/^\{(master|backup)(:\d+)?\}/);
 
+	return(0) if ($junos::ShowChassisFirmware);
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
 	/Unrecognized command/ && return(1);
@@ -239,6 +243,7 @@ sub ShowChassisFirmware {
 
 	ProcessHistory("","","","# $_");
     }
+    $ShowChassisFirmware = 1;
     return(0);
 }
 
@@ -412,6 +417,36 @@ sub ShowSystemAutoinstall {
     return(0);
 }
 
+# This routine parses "show system configuration database usage"
+# XXX this does not work with older JunOS because the unrecognized command
+#     is mangled by the cli parser and then does not match what was sent!
+#     so, this is a stand-alone function for now.
+sub ShowSystemConfDB {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In ShowSystemConfDB: $_" if ($debug);
+
+    s/^[a-z]+@//;
+    ProcessHistory("","","","# $_");
+    while (<$INPUT>) {
+	tr/\015//d;
+	($found_end = 1, last) if (/^$prompt/);
+	next if (/^system (shutdown message from|going down )/i);
+	next if (/^\{(master|backup)(:\d+)?\}/);
+
+	/Unrecognized command/ && return(0);
+	/command is not valid/ && return(0);
+	/^\s+\^/ && return(0);
+	/syntax error/ && return(0);
+
+	# trim fractional part of the sizes to reduce churn
+	s/\.\d+ ([GKM]B)/ $1/;
+
+	ProcessHistory("","","","# $_");
+    }
+    return(0);
+}
+
+
 sub ShowSystemCoreDumps {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowSystemCoreDumps: $_" if ($debug);
