@@ -1,8 +1,8 @@
 package nxos;
 ##
-## $Id: nxos.pm.in 3843 2018-07-19 01:21:29Z heas $
+## $Id: nxos.pm.in 3941 2019-01-16 18:55:02Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -57,15 +57,9 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.8;
+use rancid 3.9;
 
 our $proc;
-our $ios;
-our $found_version;
-our $found_env;
-our $found_diag;
-our $config_register;			# configuration register value
-
 our $type;				# device model, from ShowVersion
 
 our $C0;				# output formatting control
@@ -84,11 +78,6 @@ sub import {
 # post-open(collection file) initialization
 sub init {
     $proc = "";
-    $found_version = 0;
-    $found_env = 0;
-    $found_diag = 0;
-    $config_register = undef;		# configuration register value
-
     $type = undef;			# device model, from ShowVersion
 
     $C0 = 0;				# output formatting control
@@ -176,7 +165,7 @@ sub ShowVersion {
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
 
-	if (/^Cisco Nexus Operating System/) { $type = "NXOS";}
+	if (/^Cisco (Nexus|Storage Area Networking) Operating System/) { $type = "NXOS";}
 	if (/^Software$/) {
 	    while (<$INPUT>) {
 		tr/\015//d;
@@ -375,7 +364,7 @@ sub ShowEnvTemp {
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
 
-	s/ +$//;	# Drop trailing ' '
+	s/ +$//;	# Drop trailing spaces
 
 # Cut out CurTemp - drop the 2nd to last field.
 #--------------------------------------------------------------------
@@ -386,6 +375,8 @@ sub ShowEnvTemp {
 	if (/(control temperature|monitor temperature)/i) {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	    while (<$INPUT>) {
+		tr/\015//d;
+		goto EndShowEnvTemp if (/^$prompt/);
 		if (/(.*\s+\d+\s+\d+\s+)(\d+)(.*$)/) {
 		    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
 		}
@@ -401,6 +392,7 @@ sub ShowEnvTemp {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	}
     }
+EndShowEnvTemp:
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
 }
@@ -463,7 +455,7 @@ sub ShowEnvPower {
 # Total Power Input (actual draw)                             161.00 W
 # Total Power Allocated (budget)                                N/A
 # Total Power Available for additional modules                  N/A  
-# 
+#
 # nexus#
 	if (/(.* +)(\d+ W +\d+ W)( +\d+ W.+)/) {
 	    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
@@ -537,12 +529,15 @@ sub DirSlotN {
 	# Drop bootvar_debug log files
 	/\s+bootvar_debug\./ && next;
 
-	# Drop accounting.log
-	/\s+accounting\.log$/ && next;
+	# Drop accounting.log*
+	/\s+accounting.log.*/ && next;
 
 	# Drop vtp_debug.log and vtp_debug_old.log CDETS bug CSCuy87611
 	/\s+vtp_debug(_old)?\.log$/ && next;
 
+	# Drop bcm_mem_lock_trace.log
+	/\s+bcm_mem_lock_trace\.log$/ && next;
+
 	next if (/BufferMonitor-1HourData/);
 
 	if (/( debug_logs| log)\/$/) {
@@ -616,6 +611,9 @@ sub ShowIntTransceiver {
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
 
+	# filter out oscillating data from transceivers
+	next if (/(Temperature|Current|Power|Voltage)\s+:/);
+
 	ProcessHistory("COMMENTS","","","!$_");
     }
     ProcessHistory("COMMENTS","","","!\n");
