@@ -1,8 +1,8 @@
 package panos;
 ##
-## $Id: panos.pm.in 3226 2016-01-15 21:41:54Z heas $
+## $Id: panos.pm.in 3928 2018-11-16 18:50:36Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -64,7 +64,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.8;
+use rancid 3.9;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -160,6 +160,23 @@ sub ShowInfo {
     return(0);
 }
 
+# This routine parses "show chassis inventory"
+sub ShowInventory {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    my($slot);
+
+    print STDERR "    In ShowInventory:: $_" if ($debug);
+
+    while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+	return(1) if (/^Invalid syntax/);
+
+	ProcessHistory("INV","","","#$_");
+    }
+    ProcessHistory("INV","","","#\n");
+    return(0);
+}
 
 # This routine parses "show config running"
 sub ShowConfig {
