@@ -1,8 +1,8 @@
 package sros;
 ##
-## $Id: sros.pm.in 3840 2018-07-16 21:57:17Z heas $
+## $Id: sros.pm.in 3939 2019-01-16 18:53:34Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -57,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.8;
+use rancid 3.9;
 
 our $proc;
 our $memoryseen;
@@ -82,7 +82,6 @@ sub init {
     ProcessHistory("COMMENTS","keysort","C0","#\n");	# show information
     ProcessHistory("COMMENTS","keysort","D0","#\n");    # show redundancy
     ProcessHistory("COMMENTS","keysort","E0","#\n");	# show chassis
-    ProcessHistory("COMMENTS","keysort","F0","#\n");	# show bootlog
 
     0;
 }
@@ -98,7 +97,8 @@ CMD:	if (/[#]\s?logout\s*$/) {
 	    $clean_run = 1;
 	    last;
 	}
-	if (/^Error:/ && ! /^Error: Invalid parameter\./) {
+	if (/^Error:/ &&
+	    !(/^Error: Invalid parameter\./ || /^Error: Bad command\./)) {
 	    print STDOUT ("$host clogin error: $_");
 	    print STDERR ("$host clogin error: $_") if ($debug);
 	    $clean_run = 0;
@@ -145,7 +145,6 @@ CMD:	if (/[#]\s?logout\s*$/) {
 sub BootLog {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In BootLog: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","F0","# $_");
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -156,21 +155,7 @@ sub BootLog {
 	return(-1) if (/minor: cli command not allowed for this user/i);
         # if file doesn't exist, return 0
         return(0) if (/minor: cli could not access file/i);
-	# context lines
-	/^\[]$/i && next;
-	/^INFO: CLI #\d+: Switching to the .* engine/ && next;
-	/file type bootlog/i && next;
 
-	/time from clock is/i && next;
-	/^(text:|executing|login:)/i && next;
-	/^File/i && next;
-	/[-=]+$/i && next;
-	/executed [0-9,]+ lines in [0-9.]+ seconds/i && next;
-
-	if (/chassis serial number is \'(\S+)\'/i) {
-	    ProcessHistory("COMMENTS","keysort","B3",
-			   "#Chassis serial number: $1\n");
-	}
 	if (/total memory:\s+(\S+)\s+chassis type:\s+(\S+)\s+card type:\s+(\S+)/i) {
 	    next if ($memoryseen++);
 	    ProcessHistory("COMMENTS","keysort","A1",
@@ -180,8 +165,9 @@ sub BootLog {
 	    ProcessHistory("COMMENTS","keysort","B2",
 			   "#Card type: $3\n");
 	}
-
-	ProcessHistory("COMMENTS","keysort","F0","# $_");
+	/^chassis serial number is \'(.*)\'/i &&
+	    ProcessHistory("COMMENTS","keysort","B1",
+			   "#Chassis serial number: $1\n") && next;
     }
 }
 # This routine parses "show bof"
@@ -227,6 +213,7 @@ sub ShowCardDetail {
 	next if (/^(Config file|BOF) last (saved|modified)\s+:/ && ($filter_osc >= 2));
 
 	/[-=]+$/i && next;
+
 	ProcessHistory("COMMENTS","keysort","E6","# $_");
     }
 }
@@ -268,6 +255,15 @@ sub ShowChassis {
 	/^$/i && next; # extra blank lines tr doesn't remove
 
 	/[-=]+$/i && next;
+
+	/^\s+type\s+:\s+(.*)/i &&
+	    ProcessHistory("COMMENTS","keysort","E1","# $_") &&
+	    next;
+	/^\s+serial number\s+:\s+(.*)/i &&
+	    ProcessHistory("COMMENTS","keysort","B1",
+			   "#Chassis serial number: $1\n") &&
+	    ProcessHistory("COMMENTS","keysort","E1","# $_") &&
+	    next;
 	ProcessHistory("COMMENTS","keysort","E1","# $_");
     }
 }
