@@ -1,8 +1,8 @@
 package wavesvros;
 ##
-## $Id: wavesvros.pm.in 3723 2017-07-31 21:27:57Z heas $
+## $Id: wavesvros.pm.in 3860 2018-08-11 12:02:29Z heas $
 ##
-## rancid 3.8
+## rancid 3.9
 ## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -58,7 +58,7 @@ require(Exporter);
 our @ISA = qw(Exporter);
 $Exporter::Verbose=1;
 
-use rancid 3.8;
+use rancid 3.9;
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -141,9 +141,29 @@ TOP: while (<$INPUT>) {
     }
 }
 
+# This routine parses a few commands generically
+sub GenericCmd {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In GenericCmd: $_" if ($debug);
+
+    # include the command
+    s/^[a-z]+@//; s/^([^ ]+)\*([>#])/$1$2/;
+    ProcessHistory("","","","! $_");
+    while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+
+	ProcessHistory("","","","! $_");
+    }
+    ProcessHistory("","","","!\n");
+
+    return(0);
+}
+
 # This routine parses "chassis show"
 sub ShowChassis {
     my($INPUT, $OUTPUT, $cmd) = @_;
+    my($PSW) = 0;
     print STDERR "    In ShowChassisClocks: $_" if ($debug);
 
     # include the command
@@ -154,21 +174,36 @@ sub ShowChassis {
 	last if (/^$prompt/);
 	/no matching entry found/ && return(-1);	# unknown cmd
 
-	# skip fan status
-	if (/CFU FAN STATUS/) {
+	# skip fan status/chassis power draw
+	if (/(cfu fan status|chassis power summary)/i) {
 	    while (<$INPUT>) {
 		tr/\015//d;
 		return(-1) if (/^$prompt/);
 		last if (/^\s*$/);
 	    }
 	}
+	# filter PS wattage from power supply status
+	if (/power supply status/i) {
+	    ProcessHistory("","","","! $_");
+	    while (<$INPUT>) {
+		tr/\015//d;
+		goto EndShowChassis if (/^$prompt/);
+		$PSW = 1 if (/power \(w\)/i);
+		if ($PSW && /^((?:\|[^|]+){7,})\|\s+(?:[0-9.]+ \|)/) {
+		    ProcessHistory("","","","! $1|\n");
+		} else {
+		    ProcessHistory("","","","! $_");
+		}
+		last if (/^\s*$/);
+	    }
+	}
 
 	ProcessHistory("","","","! $_");
     }
+EndShowChassis:
     return(0);
 }
 
-
 # This routine parses "software show"
 sub ShowVersion {
     my($INPUT, $OUTPUT, $cmd) = @_;
